@@ -17,15 +17,16 @@
        under the License.
 */
 
-var path = require('path');
-var fs = require('fs-extra');
-var utils = require('./utils');
-var check_reqs = require('./check_reqs');
-var ROOT = path.join(__dirname, '..');
+const path = require('path');
+const fs = require('fs-extra');
+const utils = require('./utils');
+const check_reqs = require('./check_reqs');
+const ROOT = path.join(__dirname, '..');
 const { createEditor } = require('properties-parser');
+const CordovaGradleConfigParserFactory = require('./config/CordovaGradleConfigParserFactory');
 
-var CordovaError = require('cordova-common').CordovaError;
-var AndroidManifest = require('./AndroidManifest');
+const CordovaError = require('cordova-common').CordovaError;
+const AndroidManifest = require('./AndroidManifest');
 
 // Export all helper functions, and make sure internally within this module, we
 // reference these methods via the `exports` object - this helps with testing
@@ -43,9 +44,9 @@ function getFrameworkDir (projectPath, shared) {
 }
 
 function copyJsAndLibrary (projectPath, shared, projectName, targetAPI) {
-    var nestedCordovaLibPath = getFrameworkDir(projectPath, false);
-    var srcCordovaJsPath = path.join(ROOT, 'templates', 'project', 'assets', 'www', 'cordova.js');
-    var app_path = path.join(projectPath, 'app', 'src', 'main');
+    const nestedCordovaLibPath = getFrameworkDir(projectPath, false);
+    const srcCordovaJsPath = path.join(ROOT, 'templates', 'project', 'assets', 'www', 'cordova.js');
+    const app_path = path.join(projectPath, 'app', 'src', 'main');
     const platform_www = path.join(projectPath, 'platform_www');
 
     fs.copySync(srcCordovaJsPath, path.join(app_path, 'assets', 'www', 'cordova.js'));
@@ -56,7 +57,7 @@ function copyJsAndLibrary (projectPath, shared, projectName, targetAPI) {
     fs.copySync(srcCordovaJsPath, path.join(platform_www, 'cordova.js'));
 
     if (shared) {
-        var relativeFrameworkPath = path.relative(projectPath, getFrameworkDir(projectPath, true));
+        const relativeFrameworkPath = path.relative(projectPath, getFrameworkDir(projectPath, true));
         fs.symlinkSync(relativeFrameworkPath, nestedCordovaLibPath, 'dir');
     } else {
         fs.ensureDirSync(nestedCordovaLibPath);
@@ -73,9 +74,9 @@ function copyJsAndLibrary (projectPath, shared, projectName, targetAPI) {
 }
 
 function extractSubProjectPaths (data) {
-    var ret = {};
-    var r = /^\s*android\.library\.reference\.\d+=(.*)(?:\s|$)/mg;
-    var m;
+    const ret = {};
+    const r = /^\s*android\.library\.reference\.\d+=(.*)(?:\s|$)/mg;
+    let m;
     while ((m = r.exec(data))) {
         ret[m[1]] = 1;
     }
@@ -83,13 +84,13 @@ function extractSubProjectPaths (data) {
 }
 
 function writeProjectProperties (projectPath, target_api) {
-    var dstPath = path.join(projectPath, 'project.properties');
-    var templatePath = path.join(ROOT, 'templates', 'project', 'project.properties');
-    var srcPath = fs.existsSync(dstPath) ? dstPath : templatePath;
+    const dstPath = path.join(projectPath, 'project.properties');
+    const templatePath = path.join(ROOT, 'templates', 'project', 'project.properties');
+    const srcPath = fs.existsSync(dstPath) ? dstPath : templatePath;
 
-    var data = fs.readFileSync(srcPath, 'utf8');
+    let data = fs.readFileSync(srcPath, 'utf8');
     data = data.replace(/^target=.*/m, 'target=' + target_api);
-    var subProjects = extractSubProjectPaths(data);
+    let subProjects = extractSubProjectPaths(data);
     subProjects = subProjects.filter(function (p) {
         return !(/^CordovaLib$/m.exec(p) ||
                  /[\\/]cordova-android[\\/]framework$/m.exec(p) ||
@@ -100,7 +101,7 @@ function writeProjectProperties (projectPath, target_api) {
     if (!/\n$/.exec(data)) {
         data += '\n';
     }
-    for (var i = 0; i < subProjects.length; ++i) {
+    for (let i = 0; i < subProjects.length; ++i) {
         data += 'android.library.reference.' + (i + 1) + '=' + subProjects[i] + '\n';
     }
     fs.writeFileSync(dstPath, data);
@@ -108,29 +109,24 @@ function writeProjectProperties (projectPath, target_api) {
 
 // This makes no sense, what if you're building with a different build system?
 function prepBuildFiles (projectPath) {
-    var buildModule = require('./builders/builders');
+    const buildModule = require('./builders/builders');
     buildModule.getBuilder(projectPath).prepBuildFiles();
 }
 
-function copyBuildRules (projectPath, isLegacy) {
-    var srcDir = path.join(ROOT, 'templates', 'project');
+function copyBuildRules (projectPath) {
+    const srcDir = path.join(ROOT, 'templates', 'project');
 
-    if (isLegacy) {
-        // The project's build.gradle is identical to the earlier build.gradle, so it should still work
-        fs.copySync(path.join(srcDir, 'legacy', 'build.gradle'), path.join(projectPath, 'legacy', 'build.gradle'));
-        fs.copySync(path.join(srcDir, 'wrapper.gradle'), path.join(projectPath, 'wrapper.gradle'));
-    } else {
-        fs.copySync(path.join(srcDir, 'build.gradle'), path.join(projectPath, 'build.gradle'));
-        fs.copySync(path.join(srcDir, 'app', 'build.gradle'), path.join(projectPath, 'app', 'build.gradle'));
-        fs.copySync(path.join(srcDir, 'app', 'repositories.gradle'), path.join(projectPath, 'app', 'repositories.gradle'));
-        fs.copySync(path.join(srcDir, 'repositories.gradle'), path.join(projectPath, 'repositories.gradle'));
-        fs.copySync(path.join(srcDir, 'wrapper.gradle'), path.join(projectPath, 'wrapper.gradle'));
-    }
+    fs.copySync(path.join(srcDir, 'build.gradle'), path.join(projectPath, 'build.gradle'));
+    fs.copySync(path.join(srcDir, 'app', 'build.gradle'), path.join(projectPath, 'app', 'build.gradle'));
+    fs.copySync(path.join(srcDir, 'app', 'repositories.gradle'), path.join(projectPath, 'app', 'repositories.gradle'));
+    fs.copySync(path.join(srcDir, 'repositories.gradle'), path.join(projectPath, 'repositories.gradle'));
+
+    copyGradleTools(projectPath);
 }
 
 function copyScripts (projectPath) {
-    var srcScriptsDir = path.join(ROOT, 'templates', 'cordova');
-    var destScriptsDir = path.join(projectPath, 'cordova');
+    const srcScriptsDir = path.join(ROOT, 'templates', 'cordova');
+    const destScriptsDir = path.join(projectPath, 'cordova');
     // Delete old scripts directory if this is an update.
     fs.removeSync(destScriptsDir);
     // Copy in the new ones.
@@ -146,7 +142,7 @@ function validatePackageName (package_name) {
     // Make the package conform to Java package types
     // http://developer.android.com/guide/topics/manifest/manifest-element.html#package
     // Enforce underscore limitation
-    var msg = 'Error validating package name. ';
+    const msg = 'Error validating package name. ';
 
     if (!/^[a-zA-Z][a-zA-Z0-9_]+(\.[a-zA-Z][a-zA-Z0-9_]*)+$/.test(package_name)) {
         return Promise.reject(new CordovaError(msg + 'Must look like: `com.company.Name`. Currently is: `' + package_name + '`'));
@@ -166,7 +162,7 @@ function validatePackageName (package_name) {
  * otherwise.
  */
 function validateProjectName (project_name) {
-    var msg = 'Error validating project name. ';
+    const msg = 'Error validating project name. ';
     // Make sure there's something there
     if (project_name === '') {
         return Promise.reject(new CordovaError(msg + 'Project name cannot be empty'));
@@ -175,6 +171,12 @@ function validateProjectName (project_name) {
     return Promise.resolve();
 }
 
+function copyGradleTools (projectPath) {
+    const srcDir = path.join(ROOT, 'templates', 'project');
+
+    fs.copySync(path.resolve(srcDir, 'tools'), path.resolve(projectPath, 'tools'));
+}
+
 /**
  * Creates an android application with the given options.
  *
@@ -203,11 +205,12 @@ exports.create = function (project_path, config, options, events) {
         return Promise.reject(new CordovaError('Project already exists! Delete and recreate'));
     }
 
-    var package_name = config.android_packageName() || config.packageName() || 'io.cordova.helloCordova';
-    var project_name = config.name() || 'Hello Cordova';
+    const package_name = config.android_packageName() || config.packageName() || 'io.cordova.helloCordova';
+    const project_name = config.name() || 'Hello Cordova';
 
-    var safe_activity_name = config.android_activityName() || options.activityName || 'MainActivity';
-    var target_api = check_reqs.get_target(project_path);
+    const safe_activity_name = config.android_activityName() || options.activityName || 'MainActivity';
+    const target_api = check_reqs.get_target(project_path);
+    const compile_api = check_reqs.get_compile(project_path);
 
     // Make the package conform to Java package types
     return exports.validatePackageName(package_name)
@@ -220,12 +223,13 @@ exports.create = function (project_path, config, options, events) {
             events.emit('log', '\tPackage: ' + package_name);
             events.emit('log', '\tName: ' + project_name);
             events.emit('log', '\tActivity: ' + safe_activity_name);
-            events.emit('log', '\tAndroid target: ' + target_api);
+            events.emit('log', '\tAndroid Target SDK: ' + target_api);
+            events.emit('log', '\tAndroid Compile SDK: ' + compile_api);
 
             events.emit('verbose', 'Copying android template project to ' + project_path);
 
-            var project_template_dir = options.customTemplate || path.join(ROOT, 'templates', 'project');
-            var app_path = path.join(project_path, 'app', 'src', 'main');
+            const project_template_dir = options.customTemplate || path.join(ROOT, 'templates', 'project');
+            const app_path = path.join(project_path, 'app', 'src', 'main');
 
             // copy project template
             fs.ensureDirSync(app_path);
@@ -240,17 +244,22 @@ exports.create = function (project_path, config, options, events) {
             exports.copyJsAndLibrary(project_path, options.link, safe_activity_name, target_api);
 
             // Set up ther Android Studio paths
-            var java_path = path.join(app_path, 'java');
-            var assets_path = path.join(app_path, 'assets');
-            var resource_path = path.join(app_path, 'res');
+            const java_path = path.join(app_path, 'java');
+            const assets_path = path.join(app_path, 'assets');
+            const resource_path = path.join(app_path, 'res');
             fs.ensureDirSync(java_path);
             fs.ensureDirSync(assets_path);
             fs.ensureDirSync(resource_path);
 
+            // store package name in cdv-gradle-config
+            const cdvGradleConfig = CordovaGradleConfigParserFactory.create(project_path);
+            cdvGradleConfig.setPackageName(package_name)
+                .write();
+
             // interpolate the activity name and package
-            var packagePath = package_name.replace(/\./g, path.sep);
-            var activity_dir = path.join(java_path, packagePath);
-            var activity_path = path.join(activity_dir, safe_activity_name + '.java');
+            const packagePath = package_name.replace(/\./g, path.sep);
+            const activity_dir = path.join(java_path, packagePath);
+            const activity_path = path.join(activity_dir, safe_activity_name + '.java');
 
             fs.ensureDirSync(activity_dir);
             fs.copySync(path.join(project_template_dir, 'Activity.java'), activity_path);
@@ -258,11 +267,10 @@ exports.create = function (project_path, config, options, events) {
             utils.replaceFileContents(path.join(app_path, 'res', 'values', 'strings.xml'), /__NAME__/, utils.escape(project_name));
             utils.replaceFileContents(activity_path, /__ID__/, package_name);
 
-            var manifest = new AndroidManifest(path.join(project_template_dir, 'AndroidManifest.xml'));
-            manifest.setPackageId(package_name)
-                .getActivity().setName(safe_activity_name);
+            const manifest = new AndroidManifest(path.join(project_template_dir, 'AndroidManifest.xml'));
+            manifest.getActivity().setName(safe_activity_name);
 
-            var manifest_path = path.join(app_path, 'AndroidManifest.xml');
+            const manifest_path = path.join(app_path, 'AndroidManifest.xml');
             manifest.write(manifest_path);
 
             exports.copyScripts(project_path);
@@ -276,8 +284,8 @@ exports.create = function (project_path, config, options, events) {
 };
 
 function generateDoneMessage (type, link) {
-    var pkg = require('../package');
-    var msg = 'Android project ' + (type === 'update' ? 'updated ' : 'created ') + 'with ' + pkg.name + '@' + pkg.version;
+    const pkg = require('../package');
+    let msg = 'Android project ' + (type === 'update' ? 'updated ' : 'created ') + 'with ' + pkg.name + '@' + pkg.version;
     if (link) {
         msg += ' and has a linked CordovaLib';
     }
@@ -286,7 +294,7 @@ function generateDoneMessage (type, link) {
 
 // Returns a promise.
 exports.update = function (projectPath, options, events) {
-    var errorString =
+    const errorString =
         'An in-place platform update is not supported. \n' +
         'The `platforms` folder is always treated as a build artifact in the CLI workflow.\n' +
         'To update your platform, you have to remove, then add your android platform again.\n' +
